==> kadaster-gds2-1.2-sources.jar: nl/kadaster/schemas/gds2/afgifte_proces/v20130701/ObjectFactory.java <==

package nl.kadaster.schemas.gds2.afgifte_proces.v20130701;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.datatype.XMLGregorianCalendar;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the nl.kadaster.schemas.gds2.afgifte_proces.v20130701 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _Sortering_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20130701", "Sortering");
    private final static QName _NogNietGerapporteerd_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20130701", "NogNietGerapporteerd");
    private final static QName _MeerAfgiftesBeschikbaar_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20130701", "MeerAfgiftesBeschikbaar");
    private final static QName _BeschikbaarTot_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20130701", "BeschikbaarTot");
    private final static QName _Periode_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20130701", "Periode");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: nl.kadaster.schemas.gds2.afgifte_proces.v20130701
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link FilterDatumTijdType }
     * 
     */
    public FilterDatumTijdType createFilterDatumTijdType() {
        return new FilterDatumTijdType();
    }

    /**
     * Create an instance of {@link SorteringType }
     * 
     */
    public SorteringType createSorteringType() {
        return new SorteringType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SorteringType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20130701", name = "Sortering")
    public JAXBElement<SorteringType> createSortering(SorteringType value) {
        return new JAXBElement<SorteringType>(_Sortering_QNAME, SorteringType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Boolean }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20130701", name = "NogNietGerapporteerd")
    public JAXBElement<Boolean> createNogNietGerapporteerd(Boolean value) {
        return new JAXBElement<Boolean>(_NogNietGerapporteerd_QNAME, Boolean.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Object }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20130701", name = "MeerAfgiftesBeschikbaar")
    public JAXBElement<Object> createMeerAfgiftesBeschikbaar(Object value) {
        return new JAXBElement<Object>(_MeerAfgiftesBeschikbaar_QNAME, Object.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link XMLGregorianCalendar }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20130701", name = "BeschikbaarTot")
    public JAXBElement<XMLGregorianCalendar> createBeschikbaarTot(XMLGregorianCalendar value) {
        return new JAXBElement<XMLGregorianCalendar>(_BeschikbaarTot_QNAME, XMLGregorianCalendar.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link FilterDatumTijdType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20130701", name = "Periode")
    public JAXBElement<FilterDatumTijdType> createPeriode(FilterDatumTijdType value) {
        return new JAXBElement<FilterDatumTijdType>(_Periode_QNAME, FilterDatumTijdType.class, null, value);
    }

}

==> kadaster-gds2-2.5-sources.jar: nl/kadaster/schemas/gds2/afgifte_proces/v20130701/ObjectFactory.java <==

package nl.kadaster.schemas.gds2.afgifte_proces.v20130701;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.datatype.XMLGregorianCalendar;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the nl.kadaster.schemas.gds2.afgifte_proces.v20130701 package. 
 * &lt;p&gt;An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _Periode_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20130701", "Periode");
    private final static QName _NogNietGerapporteerd_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20130701", "NogNietGerapporteerd");
    private final static QName _MeerAfgiftesBeschikbaar_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20130701", "MeerAfgiftesBeschikbaar");
    private final static QName _BeschikbaarTot_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20130701", "BeschikbaarTot");
    private final static QName _Sortering_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20130701", "Sortering");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: nl.kadaster.schemas.gds2.afgifte_proces.v20130701
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link FilterDatumTijdType }
     * 
     */
    public FilterDatumTijdType createFilterDatumTijdType() {
        return new FilterDatumTijdType();
    }

    /**
     * Create an instance of {@link SorteringType }
     * 
     */
    public SorteringType createSorteringType() {
        return new SorteringType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link FilterDatumTijdType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link FilterDatumTijdType }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20130701", name = "Periode")
    public JAXBElement<FilterDatumTijdType> createPeriode(FilterDatumTijdType value) {
        return new JAXBElement<FilterDatumTijdType>(_Periode_QNAME, FilterDatumTijdType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Boolean }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link Boolean }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20130701", name = "NogNietGerapporteerd")
    public JAXBElement<Boolean> createNogNietGerapporteerd(Boolean value) {
        return new JAXBElement<Boolean>(_NogNietGerapporteerd_QNAME, Boolean.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Object }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link Object }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20130701", name = "MeerAfgiftesBeschikbaar")
    public JAXBElement<Object> createMeerAfgiftesBeschikbaar(Object value) {
        return new JAXBElement<Object>(_MeerAfgiftesBeschikbaar_QNAME, Object.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link XMLGregorianCalendar }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link XMLGregorianCalendar }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20130701", name = "BeschikbaarTot")
    public JAXBElement<XMLGregorianCalendar> createBeschikbaarTot(XMLGregorianCalendar value) {
        return new JAXBElement<XMLGregorianCalendar>(_BeschikbaarTot_QNAME, XMLGregorianCalendar.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SorteringType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link SorteringType }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-proces/v20130701", name = "Sortering")
    public JAXBElement<SorteringType> createSortering(SorteringType value) {
        return new JAXBElement<SorteringType>(_Sortering_QNAME, SorteringType.class, null, value);
    }

}
